@@ -2,9 +2,9 @@ from tinydb import TinyDB, Query
 from pgkit.application.settings import DB_PATH
 
 
-class DBClass():
+class DBClass:
     def __init__(self, db_path):
-        self.db = TinyDB(db_path)
+        self.db = TinyDB(db_path, create_dirs=True)
         self.config_table = self.db.table('config')
 
     def add_config(self, name, version, host, port, dbname, slot, username, password, replica_port):
@@ -24,7 +24,13 @@ class DBClass():
         self.config_table.remove(Query().name == name)
 
     def get_config(self, name):
+        results = self.config_table.search(Query().name == name)
+        if not results:
+            raise ValueError(f'No config found by the name {name}')
         return self.config_table.search(Query().name == name)[0]
 
+    def get_configs_list(self):
+        return [item['name'] for item in self.config_table.all()]
+
 
 DB = DBClass(DB_PATH)
