@@ -1,3 +1,5 @@
+import yaml
+
 import click
 from pgkit.application.db import DB
 from pgkit.application.utils import get_free_port
@@ -16,9 +18,11 @@ def config():
 @click.option('--dbname', help='Database Name', required=True, prompt=True)
 @click.option('--slot', help='Slot Name', required=True, prompt=True)
 @click.option('--username', help='Username', required=True, prompt=True)
-@click.option('--password', help='Username', required=True, prompt=True, hide_input=True)
-def add(name, version, host, port, dbname, slot, username, password):
-    replica_port = get_free_port()
+@click.option('--password', help='Password', required=True, prompt=True, hide_input=True)
+@click.option('--replica-port', help='Replica Port', required=False, prompt=True)
+def add(name, version, host, port, dbname, slot, username, password, replica_port):
+    if not replica_port:
+        replica_port = get_free_port()
     DB.add_config(name, version, host, port, dbname, slot, username, password, replica_port)
 
 
@@ -29,3 +33,12 @@ def remove(name, dangerous):
     if not dangerous:
         return click.echo('Removal requires --dangerous flag.')
     DB.remove_config(name)
+
+
+@config.command()
+@click.argument('name', required=True)
+def get(name):
+    try:
+        return click.echo(yaml.dump(dict(DB.get_config(name))))
+    except ValueError as e:
+        raise click.BadParameter(message=str(e), param=name, param_hint='NAME')
